@@ -1,7 +1,7 @@
 package Pod::Weaver::Plugin::Bencher::Scenario;
 
 our $DATE = '2019-02-24'; # DATE
-our $VERSION = '0.241'; # VERSION
+our $VERSION = '0.242'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -467,7 +467,6 @@ sub _process_bencher_scenario_or_acme_cpanmodules_module {
 
     # create Bencher::ScenarioR::* modules
     {
-        require Data::Dump;
         require Dist::Zilla::File::InMemory;
         my ($rname, $rpkg, $nsname);
         if ($is_cpanmodules) {
@@ -483,6 +482,7 @@ sub _process_bencher_scenario_or_acme_cpanmodules_module {
             name => $rname,
             content => join(
                 "",
+                "## no critic\n",
                 "package $rpkg;\n",
                 "\n",
 
@@ -492,7 +492,7 @@ sub _process_bencher_scenario_or_acme_cpanmodules_module {
 
                 "\n",
 
-                "our \$results = ", Data::Dump::dump(\@bench_res), ";\n",
+                "our \$results = ", dmp(\@bench_res), ";\n",
                 "\n",
 
                 "1;\n",
@@ -613,7 +613,7 @@ Pod::Weaver::Plugin::Bencher::Scenario - Plugin to use when building Bencher::Sc
 
 =head1 VERSION
 
-This document describes version 0.241 of Pod::Weaver::Plugin::Bencher::Scenario (from Perl distribution Pod-Weaver-Plugin-Bencher-Scenario), released on 2019-02-24.
+This document describes version 0.242 of Pod::Weaver::Plugin::Bencher::Scenario (from Perl distribution Pod-Weaver-Plugin-Bencher-Scenario), released on 2019-02-24.
 
 =head1 SYNOPSIS
 
